pub enum ParseControl {
Continue,
Accept,
Reject,
}Expand description
Action to be taken as part of an #[ingot(control)] block
during packet parsing.
Variants
Continue
Proceeds with parsing the remaining layers of a packet.
Accept
Accepts the packet if all remaining fields are Optional,
terminating parsing.
Reject
Explicitly rejects the packet.