pub enum FieldMut<'a, T: HasView<V>, V> {
Repr(&'a mut T),
Raw(&'a mut <T as HasView<V>>::ViewType),
}Expand description
An equivalent to Header for header fields which are accessed by
mutable reference.
Variants
Repr(&'a mut T)
Mutable reference to the owned representation of a field.
Raw(&'a mut <T as HasView<V>>::ViewType)
Mutable reference to a field in a borrowed header, which may be owned or borrowed depdendent on past modifications.