pub enum BoxedHeader<O, B> {
Repr(Box<O>),
Raw(B),
}Expand description
A header which is either owned or read from a buffer, which heap-allocates if the data is owned.
Generally, use of boxed Repr values reduces output struct sizes
when parsing full packets and is preferred when compiling with the
alloc feature. See InlineHeader if stack allocation is needed.
Variants
Repr(Box<O>)
Owned, in-memory representation of a header.
Raw(B)
Packed representation of a header, read from an existing buffer.
Implementations
Sourceimpl<O, B> BoxedHeader<O, B>
impl<O, B> BoxedHeader<O, B>
Sourcepub fn repr(&self) -> Option<&O>
pub fn repr(&self) -> Option<&O>
Return a reference to this packet’s contents if they are owned.
Sourcepub fn repr_mut(&mut self) -> Option<&mut O>
pub fn repr_mut(&mut self) -> Option<&mut O>
Return a mutable reference to this packet’s contents if they are owned.