InlineHeader

Enum InlineHeader 

pub enum InlineHeader<O, B> {
    Repr(O),
    Raw(B),
}
A header which is either owned or read from a buffer.

Generated traits which allow reading/modifying/emitting either type are re-implemented on the Packet types.

Variants



Repr(O)

Owned representation of a header.



Raw(B)

Packed representation of a header, read from an existing buffer.

Implementations

Source

impl<O, B> InlineHeader<O, B>

pub fn repr(&self) -> Option<&O>

Return a reference to this packet’s contents if they are owned.

pub fn repr_mut(&mut self) -> Option<&mut O>

Return a mutable reference to this packet’s contents if they are owned.

pub fn raw(&self) -> Option<&B>

Return a reference to this packet’s contents if they are borrowed.

pub fn raw_mut(&mut self) -> Option<&mut B>

Return a mutable reference to this packet’s contents if they are borrowed.