HeaderOf

Type Alias HeaderOf 

pub type HeaderOf<T, B> = Header<T, <T as HasView<B>>::ViewType>;
The Header type corresponding to an owned representation type T on buffer B.

Aliased Type

pub enum HeaderOf<T, B> {
    Repr(Box<T>),
    Raw(<T as HasView<B>>::ViewType),
}

Variants



Repr(Box<T>)

Owned, in-memory representation of a header.



Raw(<T as HasView<B>>::ViewType)

Packed representation of a header, read from an existing buffer.