Ipv4Addr

Struct Ipv4Addr 

pub struct Ipv4Addr { /* private fields */ }
An IPv4 address

Implementations

Source

impl Ipv4Addr

pub const UNSPECIFIED: Self

An IPv4 address representing an unspecified address: 0.0.0.0

pub const fn octets(&self) -> [u8; 4]

Return the bytes of the address.

pub const fn from_octets(bytes: [u8; 4]) -> Self

Builds a new address from bytes

pub const fn is_multicast(&self) -> bool

Returns true if the address is a multicast address.

pub const fn is_broadcast(&self) -> bool

Returns true if the address is a local broadcast address.

pub const fn is_private(&self) -> bool

Returns true if the address is a private address.

pub const fn is_loopback(&self) -> bool

Returns true if the address is a loopback address.

pub const fn is_unicast(&self) -> bool

Returns true if the address is a unicast address.

Returns true if the address is a link-local address.

pub const fn is_global(&self) -> bool

Returns true if the address is a global unicast address.

pub const fn is_documentation(&self) -> bool

Returns true if the address is a documentation address. There are three such unicast ranges IETF RFC 5737:

  • 192.0.2.0/24
  • 198.51.100.0/24
  • 203.0.113.0/24

And one multicast (IETF RFC 5771 / IETF RFC 6676) one:

  • 233.252.0.0/24
pub const fn is_reserved(&self) -> bool

Returns true if the address is a reserved address.

Note: The underlying core::net version is not yet stable as of Rust 1.84.1.