pub struct Ipv6Addr { /* private fields */ }Expand description
An IPv6 address.
Implementations
Sourceimpl Ipv6Addr
impl Ipv6Addr
Sourcepub const UNSPECIFIED: Self
pub const UNSPECIFIED: Self
The unspecified IPv6 address, i.e., :: or all zeros.
Sourcepub const fn from_octets(bytes: [u8; 16]) -> Self
pub const fn from_octets(bytes: [u8; 16]) -> Self
Creates an Ipv6Addr from a sixteen element byte array.
Sourcepub const fn from_segments(words: [u16; 8]) -> Self
pub const fn from_segments(words: [u16; 8]) -> Self
Creates an Ipv6Addr from an eight element 16-bit array.
Sourcepub const fn segments(&self) -> [u16; 8]
pub const fn segments(&self) -> [u16; 8]
Returns an eight element 16-bit array representation of the address.
This is taken from the core Ipv6Addr implementation.
Sourcepub const fn is_multicast(&self) -> bool
pub const fn is_multicast(&self) -> bool
Returns true if the address is a multicast address.
Sourcepub const fn is_loopback(&self) -> bool
pub const fn is_loopback(&self) -> bool
Returns true if the address is a loopback address.
Sourcepub const fn is_unicast(&self) -> bool
pub const fn is_unicast(&self) -> bool
Returns true if the address is a unicast address.
Sourcepub const fn is_unicast_link_local(&self) -> bool
pub const fn is_unicast_link_local(&self) -> bool
Returns true if the address is a unicast link-local address.
Note: The underlying core::net version is not yet stable as
of Rust 1.84.1.
Sourcepub const fn is_unique_local(&self) -> bool
pub const fn is_unique_local(&self) -> bool
Returns true if the address is a unique local address.
Note: The underlying core::net version is not yet stable as
of Rust 1.84.1.
Sourcepub const fn is_unicast_global(&self) -> bool
pub const fn is_unicast_global(&self) -> bool
Returns true if the address is a global unicast address.
Sourcepub const fn is_documentation(&self) -> bool
pub const fn is_documentation(&self) -> bool
Returns true if the address is a documentation address.
Defined in IETF RFC 3849.
Note: The underlying core::net version is not yet stable as
of Rust 1.84.1.