macro_rules! zerocopy_impls {
($t:ty) => { ... };
}Expand description
Macro which defines HeaderLen and Emit for a zerocopy-type
These are necessary for the type to be used in a variable-length field.
macro_rules! zerocopy_impls {
($t:ty) => { ... };
}Macro which defines HeaderLen and Emit for a zerocopy-type
These are necessary for the type to be used in a variable-length field.