VarBytes

Type Alias VarBytes 

pub type VarBytes<V> = Header<Vec<u8>, V>;
Buffer type which can be owned or a view.

Aliased Type

pub enum VarBytes<V> {
    Repr(Box<Vec<u8>>),
    Raw(V),
}

Variants



Repr(Box<Vec<u8>>)

Owned, in-memory representation of a header.



Raw(V)

Packed representation of a header, read from an existing buffer.