pub struct Accessor<B, T> { /* private fields */ }Expand description
A tool for converting zerocopy’s Ref<_, T>s into &T/&mut T
based on need and input B mutability.
This primarily reduces pointer sizes for fixed-width packet parts as
an internal component of all Valid packets.
Zerocopy issue #368
would obviate the need for this, but I do not believe it is under active
development. It would also open us back up to allowing any B rather than
simply those which are IntoByteSlice.
Implementations
Sourceimpl<B: SplitByteSlice, T: FromBytes + IntoBytes + KnownLayout + Immutable> Accessor<B, T>
impl<B: SplitByteSlice, T: FromBytes + IntoBytes + KnownLayout + Immutable> Accessor<B, T>
Sourcepub fn read_from_prefix<'a>(buf: B) -> Result<(Self, B), ParseError>where
B: 'a + IntoBufPointer<'a>,
T: 'a,
pub fn read_from_prefix<'a>(buf: B) -> Result<(Self, B), ParseError>where
B: 'a + IntoBufPointer<'a>,
T: 'a,
Parses out a fixed-width packet chunk T from the start of a given
buffer.