CRStr

Struct CRStr 

pub struct CRStr(/* private fields */);
A static string which is jointly usable as a CStr and str.

Implementations

Source

impl CRStr

pub const fn new(data: &'static str) -> Result<Self, CRStrError>

Validate that an input UTF-8 string is null-terminated, and attempt to construct references to each kind of string.

To use, an input string must be null-terminated:

let my_crstr = CRStr::new("some text\0").unwrap();

let str: &str = my_crstr.as_ref();
let cstr: &CStr = my_crstr.as_ref();
assert_eq!(str, "some text");
assert_eq!(cstr, c"some text");

let will_fail = CRStr::new("not null-terminated");
assert!(will_fail.is_err());
pub const fn new_unchecked(data: &'static str) -> Self

CRStr::new which panics on an invalid input. Intended for static/const definitions.

static MY_STR: CRStr = CRStr::new_unchecked("some text\0");

let str: &str = MY_STR.as_ref();
let cstr: &CStr = MY_STR.as_ref();
assert_eq!(str, "some text");
assert_eq!(cstr, c"some text");
pub fn as_str(&self) -> &'static str

Use this string as a str.

pub fn as_cstr(&self) -> &'static CStr

Use this string as a CStr.