Struct Parsed

pub struct Parsed<Stack, RawPkt: Read> {
    pub headers: Stack,
    pub last_chunk: Option<RawPkt::Chunk>,
    pub data: RawPkt,
}
Successful return value from parsing a full packet header stack over a base packet buffer which is Read.

Fields

headers: Stack

A fully-parsed header stack.

last_chunk: Option<RawPkt::Chunk>

The remainder of the last chunk accessed during parsing.

data: RawPkt

The leftover packet cursor.

Remaining bytes can be accessed using Read.