RepeatedView

Struct RepeatedView 

pub struct RepeatedView<B, T: HasView<B> + NextLayer> { /* private fields */ }
A borrowed block of headers whose elements are parsed identically (i.e., using the same choice or Ingot type), and may be chained using hint values.

Implementations

Source

impl<B: ByteSlice, T: for<'a> HasView<&'a [u8]> + HasView<B> + NextLayer> RepeatedView<B, T>

pub fn iter(&self, hint: Option<T::Hint>) -> RepeatedViewIter<'_, T>

Iterates over all sub-parsed elements.

Offsets are not stored, so individual elements are re-parsed one by one.