Enum ParseError

pub enum ParseError {
    Unwanted,
    NeedsHint,
    TooSmall,
    StraddledHeader,
    NoRemainingChunks,
    CannotAccept,
    Reject,
    IllegalValue,
}
An error encountered while parsing an individual header.

Variants



Unwanted

Encountered a header which was not allowed by a choice.



NeedsHint

No hint was provided from a previous header, but the current header requires a hint to choose



TooSmall

There are insufficient bytes in the buffer to read the intended header.



StraddledHeader

A header could not be parsed as it was split across several buffers.



NoRemainingChunks

There are no remaining chunks in the Read.



CannotAccept

A parser control attempted to accept an input packet as complete, however the remaining layers are non-optional.



Reject

The packet was explicitly rejected by a parser control block.



IllegalValue

A field in the header had an illegal value for the target datatype.

Implementations

Source

impl ParseError

pub fn as_cstr(&self) -> &'static CStr

Return the name of the error variant as a CStr.