pub enum FieldRef<'a, T: HasView<V>, V> {
Repr(&'a T),
Raw(&'a <T as HasView<V>>::ViewType),
}Expand description
An equivalent to Header for header fields which are accessed by
shared reference.
Variants
Repr(&'a T)
Reference to the owned representation of a field.
Raw(&'a <T as HasView<V>>::ViewType)
Reference to a field in a borrowed header, which may be owned or borrowed depdendent on past modifications.
Implementations