pub enum InlineHeader<O, B> {
Repr(O),
Raw(B),
}Expand description
A header which is either owned or read from a buffer.
Generated traits which allow reading/modifying/emitting either type
are re-implemented on the Packet types.
Variants
Repr(O)
Owned representation of a header.
Raw(B)
Packed representation of a header, read from an existing buffer.
Implementations
Sourceimpl<O, B> InlineHeader<O, B>
impl<O, B> InlineHeader<O, B>
Sourcepub fn repr(&self) -> Option<&O>
pub fn repr(&self) -> Option<&O>
Return a reference to this packet’s contents if they are owned.
Sourcepub fn repr_mut(&mut self) -> Option<&mut O>
pub fn repr_mut(&mut self) -> Option<&mut O>
Return a mutable reference to this packet’s contents if they are owned.