macro_rules! zerocopy_type {
(
$(#[$meta:meta])*
$vis:vis struct $name:ident($inner_vis:vis $t:ty) $(;)?
) => { ... };
(
$(#[$meta:meta])*
$vis:vis struct $name:ident {
$inner_vis:vis $inner_name:ident: $t:ty $(,)?
}
) => { ... };
}Expand description
Macro which declares a zerocopy-flavored type, which can be used in a field
The type implements all of the required derive traits, as well as
HeaderLen and Emit.