pub trait ToOwnedPacket: NextLayer {
type Target;
// Required method
fn to_owned(&self, hint: Option<Self::Hint>) -> ParseResult<Self::Target>;
}Expand description
Converts a borrowed view of a header into an owned version, possibly reparsing to do so.
This trait is used to support cases which are ambiguous on their own,
such as Repeated views over extension headers.